@@ -66,13 +66,15 @@ G_STATIC_ASSERT (sizeof (GckRealBuilder) <= sizeof (GckBuilder));
 
 EGG_SECURE_DECLARE (attributes);
 
+#define MAX_ALIGN 16
+
 static guchar *
 value_take (gpointer data,
             gsize length,
             gboolean secure)
 {
-	gsize len = length + sizeof (gint);
-	gint *value;
+	gsize len = length + MAX_ALIGN;
+	guchar *value;
 
 	if (secure)
 		value = egg_secure_realloc (data, len);
@@ -80,17 +82,17 @@ value_take (gpointer data,
 		value = g_realloc (data, len);
 	g_assert (value != NULL);
 
-	memmove (value + 1, value, length);
-	g_atomic_int_set (value, 1);
-	return (guchar *)(value + 1);
+	memmove (value + MAX_ALIGN, value, length);
+	g_atomic_int_set ((gint *)value, 1);
+	return value + MAX_ALIGN;
 }
 
 static guchar *
 value_blank (gsize length,
              gboolean secure)
 {
-	gsize len = length + sizeof (gint);
-	gint *value;
+	gsize len = length + MAX_ALIGN;
+	guchar *value;
 
 	if (secure)
 		value = egg_secure_alloc (len);
@@ -98,8 +100,8 @@ value_blank (gsize length,
 		value = g_malloc (len);
 	g_assert (value != NULL);
 
-	g_atomic_int_set (value, 1);
-	return (guchar *)(value + 1);
+	g_atomic_int_set ((gint *)value, 1);
+	return value + MAX_ALIGN;
 }
 
 static guchar *
@@ -117,12 +119,12 @@ value_new (gconstpointer data,
 static guchar *
 value_ref (guchar *data)
 {
-	gint *value = ((gint *)data) - 1;
+	guchar *value = data - MAX_ALIGN;
 	gint previous;
 
 	g_assert (data != NULL);
 
-	previous = g_atomic_int_add (value, 1);
+	previous = g_atomic_int_add ((gint *)value, 1);
 	if (G_UNLIKELY (previous <= 0)) {
 		g_warning ("An owned GckAttribute value has been modified outside of the "
 		           "gck library or an invalid attribute was passed to gck_builder_add_attribute()");
@@ -133,13 +135,13 @@ value_ref (guchar *data)
 }
 
 static void
-value_unref (gpointer data)
+value_unref (guchar *data)
 {
-	gint *value = ((gint *)data) - 1;
+	guchar *value = data - MAX_ALIGN;
 
 	g_assert (data != NULL);
 
-	if (g_atomic_int_dec_and_test (value)) {
+	if (g_atomic_int_dec_and_test ((gint *)value)) {
 		if (egg_secure_check (value))
 			egg_secure_free (value);
 		else
@@ -425,7 +427,7 @@ gck_builder_copy (GckBuilder *builder)
  * gck_builder_take_data:
  * @builder: the builder
  * @attr_type: the new attribute type
- * @value: (transfer full) (array length=length) (allow-none): the new
+ * @value: (transfer full) (array length=length) (nullable): the new
  *         attribute memory
  * @length: the length of the memory
  *
@@ -474,7 +476,7 @@ gck_builder_take_data (GckBuilder *builder,
  * gck_builder_add_data:
  * @builder: the builder
  * @attr_type: the new attribute type
- * @value: (array length=length) (allow-none): the new attribute memory
+ * @value: (array length=length) (nullable): the new attribute memory
  * @length: the length of the memory
  *
  * Add a new attribute to the builder with an arbitrary value. Unconditionally
@@ -515,7 +517,7 @@ gck_builder_add_data (GckBuilder *builder,
  * gck_builder_set_data:
  * @builder: the builder
  * @attr_type: the attribute type
- * @value: (array length=length) (allow-none): the new attribute memory
+ * @value: (array length=length) (nullable): the new attribute memory
  * @length: the length of the memory
  *
  * Set a new attribute to the builder with an arbitrary value. If an attribute
@@ -776,7 +778,7 @@ gck_builder_set_date (GckBuilder *builder,
  * gck_builder_add_string:
  * @builder: the builder
  * @attr_type: the new attribute type
- * @value: (allow-none): the attribute value
+ * @value: (nullable): the attribute value
  *
  * Add a new attribute to the builder for the string @value or %NULL.
  * Unconditionally adds a new attribute, even if one with the same @attr_type
@@ -1378,7 +1380,7 @@ gck_builder_clear (GckBuilder *builder)
 /**
  * GckAttribute:
  * @type: The attribute type, such as CKA_LABEL.
- * @value: (array length=length): The value of the attribute. May be NULL.
+ * @value: (array length=length): The value of the attribute. May be %NULL.
  * @length: The length of the attribute. May be GCK_INVALID if the attribute is invalid.
  *
  * This structure represents a PKCS11 CK_ATTRIBUTE.
@@ -1458,7 +1460,7 @@ gck_attribute_get_ulong (const GckAttribute *attr)
  * to this function unless you're know it's supposed to contain
  * a value of the right type.
  *
- * Return value: (allow-none): a null terminated string, to be freed with
+ * Return value: (nullable): a null terminated string, to be freed with
  *               g_free(), or %NULL if the value was invalid
  */
 gchar*
@@ -2055,10 +2057,10 @@ gck_attribute_hash (gconstpointer attr)
  * An allocator used to allocate data for the attributes in this GckAttributes set.
  *
  * This is a function that acts like g_realloc. Specifically it frees when length is
- * set to zero, it allocates when data is set to NULL, and it reallocates when both
+ * set to zero, it allocates when data is set to %NULL, and it reallocates when both
  * are valid.
  *
- * Returns: The allocated memory, or NULL when freeing.
+ * Returns: The allocated memory, or %NULL when freeing.
  **/
 
 GType
@@ -2320,7 +2322,7 @@ gck_attributes_ref_sink (GckAttributes *attrs)
 
 /**
  * gck_attributes_unref:
- * @attrs: (allow-none) (type Gck.Attributes): An attribute array
+ * @attrs: (nullable) (type Gck.Attributes): An attribute array
  *
  * Unreference this attribute array.
  *
@@ -2814,13 +2816,13 @@ _gck_format_attributes (GString *output,
 		if (attr->length == GCK_INVALID) {
 			g_string_append_printf (output, " (-1) INVALID");
 		} else if (_gck_attribute_is_ulong_of_type (attr, CKA_CLASS)) {
-			_gck_format_class (output, *((CK_OBJECT_CLASS_PTR)attr->value));
+			_gck_format_class (output, (CK_OBJECT_CLASS) gck_attribute_get_ulong(attr));
 		} else if (_gck_attribute_is_ulong_of_type (attr, CKA_X_ASSERTION_TYPE)) {
-			_gck_format_assertion_type (output, *((CK_X_ASSERTION_TYPE *)attr->value));
+			_gck_format_assertion_type (output, (CK_X_ASSERTION_TYPE) gck_attribute_get_ulong(attr));
 		} else if (_gck_attribute_is_ulong_of_type (attr, CKA_CERTIFICATE_TYPE)) {
-			_gck_format_certificate_type (output, *((CK_CERTIFICATE_TYPE *)attr->value));
+			_gck_format_certificate_type (output, (CK_CERTIFICATE_TYPE) gck_attribute_get_ulong(attr));
 		} else if (_gck_attribute_is_ulong_of_type (attr, CKA_KEY_TYPE)) {
-			_gck_format_key_type (output, *((CK_KEY_TYPE *)attr->value));
+			_gck_format_key_type (output, (CK_KEY_TYPE) gck_attribute_get_ulong(attr));
 		} else if (_gck_attribute_is_sensitive (attr)) {
 			g_string_append_printf (output, " (%lu) NOT-PRINTED", attr->length);
 		} else {
