@@ -41,7 +41,7 @@ setup (Test *test, gconstpointer unused)
 	GError *err = NULL;
 
 	/* Successful load */
-	test->module = gck_module_initialize (BUILDDIR "/.libs/libmock-test-module.so", NULL, &err);
+	test->module = gck_module_initialize (_GCK_TEST_MODULE_PATH, NULL, &err);
 	g_assert_no_error (err);
 	g_assert (test->module);
 	g_object_add_weak_pointer (G_OBJECT (test->module), (gpointer *)&test->module);
@@ -70,7 +70,7 @@ test_initialize_async (void)
 	GError *error = NULL;
 
 	/* Shouldn't be able to load modules */
-	gck_module_initialize_async (BUILDDIR "/.libs/libmock-test-module.so",
+	gck_module_initialize_async (_GCK_TEST_MODULE_PATH,
 	                             NULL, fetch_async_result, &result);
 
 	egg_test_wait_until (500);
@@ -138,7 +138,7 @@ test_module_props (Test *test, gconstpointer unused)
 
 	g_object_get (test->module, "path", &path, NULL);
 	g_assert (path != NULL && "no module-path");
-	g_assert (strcmp (BUILDDIR "/.libs/libmock-test-module.so", path) == 0 && "module path wrong");
+	g_assert (strcmp (_GCK_TEST_MODULE_PATH, path) == 0 && "module path wrong");
 	g_free (path);
 }
 
