@@ -355,7 +355,7 @@ test_build_with_attributes (void)
 
 	g_assert (g_str_has_prefix (uri, "pkcs11:"));
 	g_assert (strstr (uri, "object=The%20Label"));
-	g_assert (strstr (uri, "object-type=data"));
+	g_assert (strstr (uri, "object-type=data") || strstr (uri, "type=data"));
 	g_assert (strstr (uri, "id=%54%45%53%54%00") || strstr (uri, "id=TEST%00"));
 
 	g_free (uri);
@@ -432,7 +432,7 @@ test_build_objecttype_cert (void)
 
 	uri = gck_uri_build (uri_data, GCK_URI_FOR_OBJECT);
 	g_assert (uri);
-	g_assert (strstr (uri, "object-type=cert"));
+	g_assert (strstr (uri, "object-type=cert") || strstr (uri, "type=cert"));
 
 	gck_uri_data_free (uri_data);
 	g_free (uri);
@@ -451,7 +451,7 @@ test_build_objecttype_private (void)
 
 	uri = gck_uri_build (uri_data, GCK_URI_FOR_OBJECT);
 	g_assert (uri);
-	g_assert (strstr (uri, "object-type=private"));
+	g_assert (strstr (uri, "object-type=private") || strstr (uri, "type=private"));
 
 	gck_uri_data_free (uri_data);
 	g_free (uri);
@@ -470,7 +470,7 @@ test_build_objecttype_public (void)
 
 	uri = gck_uri_build (uri_data, GCK_URI_FOR_OBJECT);
 	g_assert (uri);
-	g_assert (strstr (uri, "object-type=public"));
+	g_assert (strstr (uri, "object-type=public") || strstr (uri, "type=public"));
 
 	gck_uri_data_free (uri_data);
 	g_free (uri);
@@ -489,7 +489,7 @@ test_build_objecttype_secret (void)
 
 	uri = gck_uri_build (uri_data, GCK_URI_FOR_OBJECT);
 	g_assert (uri);
-	g_assert (strstr (uri, "object-type=secret-key"));
+	g_assert (strstr (uri, "object-type=secret-key") || strstr (uri, "type=secret-key"));
 
 	gck_uri_data_free (uri_data);
 	g_free (uri);
