@@ -457,9 +457,10 @@ gcr_certificate_chain_class_init (GcrCertificateChainClass *klass)
 	 * The certificate chain status. See #GcrCertificateChainStatus
 	 */
 	g_object_class_install_property (gobject_class, PROP_STATUS,
-	           g_param_spec_enum ("status", "Status", "Status of certificate chain",
-	                              GCR_TYPE_CERTIFICATE_CHAIN_STATUS,
-	                              GCR_CERTIFICATE_CHAIN_UNKNOWN, G_PARAM_READABLE));
+		g_param_spec_enum ("status", "Status", "Status of certificate chain",
+		                   GCR_TYPE_CERTIFICATE_CHAIN_STATUS,
+		                   GCR_CERTIFICATE_CHAIN_UNKNOWN,
+		                   G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrCertificateChain:length:
@@ -467,8 +468,9 @@ gcr_certificate_chain_class_init (GcrCertificateChainClass *klass)
 	 * The length of the certificate chain.
 	 */
 	g_object_class_install_property (gobject_class, PROP_LENGTH,
-	           g_param_spec_uint ("length", "Length", "Length of certificate chain",
-	                              0, G_MAXUINT, 0, G_PARAM_READABLE));
+		g_param_spec_uint ("length", "Length", "Length of certificate chain",
+		                   0, G_MAXUINT, 0,
+		                   G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 	Q_ORIGINAL_CERT = g_quark_from_static_string ("gcr-certificate-chain-original-cert");
 	Q_OPERATION_DATA = g_quark_from_static_string ("gcr-certificate-chain-operation-data");
@@ -596,7 +598,7 @@ gcr_certificate_chain_get_status (GcrCertificateChain *self)
  * If an anchor is returned it does not mean that the certificate chain has
  * been verified, but merely that an anchor has been found.
  *
- * Returns: (transfer none): the anchor certificate, or NULL if not anchored.
+ * Returns: (transfer none): the anchor certificate, or %NULL if not anchored.
  */
 GcrCertificate *
 gcr_certificate_chain_get_anchor (GcrCertificateChain *self)
@@ -665,7 +667,7 @@ gcr_certificate_chain_get_certificate (GcrCertificateChain *self, guint index)
  * gcr_certificate_chain_build:
  * @self: the #GcrCertificateChain
  * @purpose: the purpose the certificate chain will be used for
- * @peer: (allow-none): the peer the certificate chain will be used with, or %NULL
+ * @peer: (nullable): the peer the certificate chain will be used with, or %NULL
  * @flags: chain completion flags
  * @cancellable: a #GCancellable or %NULL
  * @error: a #GError or %NULL
@@ -736,7 +738,7 @@ gcr_certificate_chain_build (GcrCertificateChain *self,
  * gcr_certificate_chain_build_async:
  * @self: the #GcrCertificateChain
  * @purpose: the purpose the certificate chain will be used for
- * @peer: (allow-none): the peer the certificate chain will be used with, or %NULL
+ * @peer: (nullable): the peer the certificate chain will be used with, or %NULL
  * @flags: chain completion flags
  * @cancellable: a #GCancellable or %NULL
  * @callback: this will be called when the operation completes.
@@ -804,7 +806,7 @@ gcr_certificate_chain_build_async (GcrCertificateChain *self,
  * gcr_certificate_chain_build_finish:
  * @self: the #GcrCertificateChain
  * @result: the #GAsyncResult passed to the callback
- * @error: a #GError, or NULL
+ * @error: a #GError, or %NULL
  *
  * Finishes an asynchronous operation started by
  * gcr_certificate_chain_build_async().
