@@ -267,7 +267,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		         g_param_spec_string ("label", "Label", "Certificate label",
-		                              "", G_PARAM_READABLE));
+		                              "", G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrCertificate:description:
@@ -276,7 +276,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		         g_param_spec_string ("description", "Description", "Description of object being rendered",
-		                              "", G_PARAM_READABLE));
+		                              "", G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrCertificate:markup:
@@ -285,7 +285,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		         g_param_spec_string ("markup", "Markup", "Markup which describes object being rendered",
-		                              "", G_PARAM_READABLE));
+		                              "", G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrCertificate:icon:
@@ -294,7 +294,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		         g_param_spec_object ("icon", "Icon", "Icon for the object being rendered",
-		                              G_TYPE_ICON, G_PARAM_READABLE));
+		                              G_TYPE_ICON, G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrCertificate:subject:
@@ -303,7 +303,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		           g_param_spec_string ("subject", "Subject", "Common name of subject",
-		                                "", G_PARAM_READABLE));
+		                                "", G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrCertificate:issuer:
@@ -312,7 +312,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		           g_param_spec_string ("issuer", "Issuer", "Common name of issuer",
-		                                "", G_PARAM_READABLE));
+		                                "", G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrCertificate:expiry:
@@ -321,7 +321,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		           g_param_spec_boxed ("expiry", "Expiry", "Certificate expiry",
-		                               G_TYPE_DATE, G_PARAM_READABLE));
+		                               G_TYPE_DATE, G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		g_once_init_leave (&initialized, 1);
 	}
@@ -363,8 +363,8 @@ gcr_certificate_get_columns (void)
 
 /**
  * gcr_certificate_compare:
- * @first: (allow-none): the certificate to compare
- * @other: (allow-none): the certificate to compare against
+ * @first: (nullable): the certificate to compare
+ * @other: (nullable): the certificate to compare against
  *
  * Compare one certificate against another. If the certificates are equal
  * then zero is returned. If one certificate is %NULL or not a certificate,
@@ -401,7 +401,7 @@ gcr_certificate_compare (GcrComparable *first, GcrComparable *other)
 
 
 /**
- * gcr_certificate_get_der_data:
+ * gcr_certificate_get_der_data: (virtual get_der_data)
  * @self: a #GcrCertificate
  * @n_data: a pointer to a location to store the size of the resulting DER data.
  *
@@ -428,7 +428,7 @@ gcr_certificate_get_der_data (GcrCertificate *self,
  * This will try to lookup the common name, orianizational unit,
  * organization in that order.
  *
- * Returns: the allocated issuer name, or NULL if no issuer name
+ * Returns: the allocated issuer name, or %NULL if no issuer name
  */
 gchar *
 gcr_certificate_get_issuer_name (GcrCertificate *self)
@@ -453,7 +453,7 @@ gcr_certificate_get_issuer_name (GcrCertificate *self)
  * The string returned should be freed by the caller when no longer
  * required.
  *
- * Returns: The allocated issuer CN, or NULL if no issuer CN present.
+ * Returns: The allocated issuer CN, or %NULL if no issuer CN present.
  */
 gchar*
 gcr_certificate_get_issuer_cn (GcrCertificate *self)
@@ -475,7 +475,7 @@ gcr_certificate_get_issuer_cn (GcrCertificate *self)
  * The string returned should be freed by the caller when no longer
  * required.
  *
- * Returns: (allow-none): the allocated part of the issuer DN, or %NULL if no
+ * Returns: (nullable): the allocated part of the issuer DN, or %NULL if no
  *          such part is present
  */
 gchar *
@@ -613,7 +613,7 @@ gcr_certificate_get_issuer_dn (GcrCertificate *self)
  * The string returned should be freed by the caller when no longer
  * required.
  *
- * Returns: The allocated subject CN, or NULL if no subject CN present.
+ * Returns: The allocated subject CN, or %NULL if no subject CN present.
  */
 gchar*
 gcr_certificate_get_subject_cn (GcrCertificate *self)
@@ -630,7 +630,7 @@ gcr_certificate_get_subject_cn (GcrCertificate *self)
  * This will try to lookup the common name, orianizational unit,
  * organization in that order.
  *
- * Returns: the allocated subject name, or NULL if no subject name
+ * Returns: the allocated subject name, or %NULL if no subject name
  */
 gchar *
 gcr_certificate_get_subject_name (GcrCertificate *self)
@@ -660,7 +660,7 @@ gcr_certificate_get_subject_name (GcrCertificate *self)
  * The string returned should be freed by the caller when no longer
  * required.
  *
- * Returns: (allow-none): the allocated part of the subject DN, or %NULL if no
+ * Returns: (nullable): the allocated part of the subject DN, or %NULL if no
  *          such part is present.
  */
 gchar*
@@ -1005,8 +1005,8 @@ gcr_certificate_get_icon (GcrCertificate *self)
 /**
  * gcr_certificate_get_basic_constraints:
  * @self: the certificate
- * @is_ca: (out) (allow-none): location to place a %TRUE if is an authority
- * @path_len: (out) (allow-none): location to place the max path length
+ * @is_ca: (out) (optional): location to place a %TRUE if is an authority
+ * @path_len: (out) (optional): location to place the max path length
  *
  * Get the basic constraints for the certificate if present. If %FALSE is
  * returned then no basic constraints are present and the @is_ca and
