@@ -178,6 +178,7 @@ static GQuark PEM_PRIVATE_KEY;
 static GQuark PEM_PKCS7;
 static GQuark PEM_PKCS12;
 static GQuark PEM_CERTIFICATE_REQUEST;
+static GQuark PEM_NEW_CERTIFICATE_REQUEST;
 static GQuark PEM_PUBLIC_KEY;
 
 static GQuark ARMOR_PGP_PUBLIC_KEY_BLOCK;
@@ -203,6 +204,7 @@ init_quarks (void)
 		QUARK (PEM_PKCS7, "PKCS7");
 		QUARK (PEM_PKCS12, "PKCS12");
 		QUARK (PEM_CERTIFICATE_REQUEST, "CERTIFICATE REQUEST");
+		QUARK (PEM_NEW_CERTIFICATE_REQUEST, "NEW CERTIFICATE REQUEST");
 		QUARK (PEM_PUBLIC_KEY, "PUBLIC KEY");
 
 		QUARK (ARMOR_PGP_PRIVATE_KEY_BLOCK, "PGP PRIVATE KEY BLOCK");
@@ -1262,7 +1264,7 @@ parse_pkcs12_bag_friendly_name (GNode *asn)
 		if (oid == GCR_OID_PKCS9_ATTRIBUTE_FRIENDLY) {
 			node = egg_asn1x_node (asn, i, "values", 1, NULL);
 			if (node != NULL) {
-				asn_str = egg_asn1x_get_any_as (node, pkix_asn1_tab, "BMPString");
+				asn_str = egg_asn1x_get_any_as_string (node, EGG_ASN1X_BMP_STRING);
 				if (asn_str) {
 					result = egg_asn1x_get_bmpstring_as_utf8 (asn_str);
 					egg_asn1x_destroy (asn_str);
@@ -1880,6 +1882,9 @@ formats_for_armor_type (GQuark armor_type,
 	} else if (armor_type == PEM_CERTIFICATE_REQUEST) {
 		*inner_format = GCR_FORMAT_DER_PKCS10;
 		*outer_format = GCR_FORMAT_PEM_PKCS10;
+	} else if (armor_type == PEM_NEW_CERTIFICATE_REQUEST) {
+		*inner_format = GCR_FORMAT_DER_PKCS10;
+		*outer_format = GCR_FORMAT_PEM_PKCS10;
 	} else if (armor_type == PEM_PKCS12) {
 		*inner_format = GCR_FORMAT_DER_PKCS12;
 		*outer_format = GCR_FORMAT_PEM_PKCS12;
