@@ -287,7 +287,8 @@ gcr_pkcs11_certificate_class_init (GcrPkcs11CertificateClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_ATTRIBUTES,
 	         g_param_spec_boxed ("attributes", "Attributes", "The data displayed in the renderer",
-	                             GCK_TYPE_ATTRIBUTES, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	                             GCK_TYPE_ATTRIBUTES,
+	                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 
 	gcr_certificate_mixin_class_init (gobject_class);
 	_gcr_initialize_library ();
@@ -339,7 +340,7 @@ gcr_pkcs11_certificate_get_attributes (GcrPkcs11Certificate *self)
  * gcr_pkcs11_certificate_lookup_issuer:
  * @certificate: a #GcrCertificate
  * @cancellable: a #GCancellable
- * @error: a #GError, or NULL
+ * @error: a #GError, or %NULL
  *
  * Lookup a the issuer of a @certificate in the PKCS\#11 storage. The
  * lookup is done using the issuer DN of the certificate. No certificate chain
@@ -414,7 +415,7 @@ gcr_pkcs11_certificate_lookup_issuer_async (GcrCertificate *certificate, GCancel
 /**
  * gcr_pkcs11_certificate_lookup_issuer_finish:
  * @result: the #GAsyncResult passed to the callback
- * @error: a #GError, or NULL
+ * @error: a #GError, or %NULL
  *
  * Finishes an asynchronous operation started by
  * gcr_pkcs11_certificate_lookup_issuer_async().
