@@ -438,7 +438,8 @@ gcr_certificate_renderer_class_init (GcrCertificateRendererClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_CERTIFICATE,
 	           g_param_spec_object ("certificate", "Certificate", "Certificate to display.",
-	                                GCR_TYPE_CERTIFICATE, G_PARAM_READWRITE));
+	                                GCR_TYPE_CERTIFICATE,
+	                                G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrCertificateRenderer:attributes:
@@ -448,7 +449,8 @@ gcr_certificate_renderer_class_init (GcrCertificateRendererClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_ATTRIBUTES,
 	           g_param_spec_boxed ("attributes", "Attributes", "Certificate pkcs11 attributes",
-	                               GCK_TYPE_ATTRIBUTES, G_PARAM_READWRITE));
+	                               GCK_TYPE_ATTRIBUTES,
+	                               G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrCertificateRenderer:label:
@@ -457,7 +459,8 @@ gcr_certificate_renderer_class_init (GcrCertificateRendererClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_LABEL,
 	           g_param_spec_string ("label", "Label", "Certificate Label",
-	                                "", G_PARAM_READWRITE));
+	                                "",
+	                                G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	gcr_certificate_mixin_class_init (gobject_class);
 
@@ -676,7 +679,7 @@ gcr_certificate_renderer_new (GcrCertificate *certificate)
 
 /**
  * gcr_certificate_renderer_new_for_attributes:
- * @label: (allow-none): the label to display
+ * @label: (nullable): the label to display
  * @attrs: The attributes to display
  *
  * Create a new certificate renderer to display the label and attributes. One
@@ -714,7 +717,7 @@ gcr_certificate_renderer_get_certificate (GcrCertificateRenderer *self)
 /**
  * gcr_certificate_renderer_set_certificate:
  * @self: The renderer
- * @certificate: (allow-none): the certificate to display
+ * @certificate: (nullable): the certificate to display
  *
  * Set a certificate to display in the renderer.
  */
@@ -744,7 +747,7 @@ gcr_certificate_renderer_set_certificate (GcrCertificateRenderer *self, GcrCerti
  *
  * Get the PKCS\#11 attributes, if any, set for this renderer to display.
  *
- * Returns: (allow-none) (transfer none): the attributes, owned by the renderer
+ * Returns: (nullable) (transfer none): the attributes, owned by the renderer
  *
  * Deprecated: 3.6: Use gcr_renderer_get_attributes() instead
  */
@@ -758,7 +761,7 @@ gcr_certificate_renderer_get_attributes (GcrCertificateRenderer *self)
 /**
  * gcr_certificate_renderer_set_attributes:
  * @self: The renderer
- * @attrs: (allow-none): attributes to set
+ * @attrs: (nullable): attributes to set
  *
  * Set the PKCS\#11 attributes for this renderer to display. One of the attributes
  * should be a CKA_VALUE type attribute containing a DER encoded certificate.
